You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2010/09/02 17:34:01 UTC

svn commit: r991984 - /camel/trunk/tests/camel-itest/src/test/java/org/apache/camel/itest/async/HttpAsyncDslTest.java

Author: davsclaus
Date: Thu Sep  2 15:34:00 2010
New Revision: 991984

URL: http://svn.apache.org/viewvc?rev=991984&view=rev
Log:
Fixed test on other boxes.

Modified:
    camel/trunk/tests/camel-itest/src/test/java/org/apache/camel/itest/async/HttpAsyncDslTest.java

Modified: camel/trunk/tests/camel-itest/src/test/java/org/apache/camel/itest/async/HttpAsyncDslTest.java
URL: http://svn.apache.org/viewvc/camel/trunk/tests/camel-itest/src/test/java/org/apache/camel/itest/async/HttpAsyncDslTest.java?rev=991984&r1=991983&r2=991984&view=diff
==============================================================================
--- camel/trunk/tests/camel-itest/src/test/java/org/apache/camel/itest/async/HttpAsyncDslTest.java (original)
+++ camel/trunk/tests/camel-itest/src/test/java/org/apache/camel/itest/async/HttpAsyncDslTest.java Thu Sep  2 15:34:00 2010
@@ -111,8 +111,8 @@ public class HttpAsyncDslTest extends Ca
                     // if the JMS ReplyTo was set then we expect a reply, otherwise not
                     // use a pool of 20 threads for the point forward
                     .threads(20)
-                    // do some CPU heavy processing of the message (we simulate and delay just 100 ms)
-                    .unmarshal(mySecureDataFormat).delay(100).to("bean:handleOrder").to("mock:order");
+                    // do some CPU heavy processing of the message (we simulate and delay just 500 ms)
+                    .unmarshal(mySecureDataFormat).delay(500).to("bean:handleOrder").to("mock:order");
                 // END SNIPPET: e1
             }
         };